#include "pc_commands.h"
#include "usb_keyboard.h"
#include "led.h"

// The current command mode.
enum pc_command_mode_t pc_command_mode = PC_COMMAND_MODE_BLU_RAY;

// Sends a command to the PC.
void pc_command_send(enum pc_command_t command) {
	
	// Is it a special command?
	switch (command) {
		case PC_COMMAND_NONE:
			return;
		case PC_COMMAND_MENU_AUTO:
			if (pc_command_mode == PC_COMMAND_MODE_BLU_RAY) {
				command = PC_COMMAND_POPUP_MENU;
			} else {
				command = PC_COMMAND_MENUS;
			}
			break;
		case PC_COMMAND_ROOT_MENU_AUTO:
			if (pc_command_mode == PC_COMMAND_MODE_BLU_RAY) {
				command = PC_COMMAND_POPUP_MENU;
			} else {
				command = PC_COMMAND_ROOT_MENU;
			}
			break;
		case PC_COMMAND_TOGGLE_MODE:
			if (pc_command_mode == PC_COMMAND_MODE_BLU_RAY) {
				pc_command_mode = PC_COMMAND_MODE_DVD;
				led_blink(LED_BLINK_PATTERN_1_LONG_2_SHORT);
			} else {
				pc_command_mode = PC_COMMAND_MODE_BLU_RAY;
				led_blink(LED_BLINK_PATTERN_1_LONG_1_SHORT);
			}
			return;
		default:
			break;
	}
	
	struct usb_keyboard_modified_key_t key = { USB_KEYBOARD_KEY_MODIFIER_NONE, USB_KEYBOARD_KEY_NONE };
	if (command & 0x80) {
		key.key = command & 0x7F;
		switch (command) {
			case PC_COMMAND_POWER:
				key.modifier = USB_KEYBOARD_KEY_MODIFIER_LEFT_ALT;
				break;
			default:
				key.modifier = USB_KEYBOARD_KEY_MODIFIER_LEFT_CONTROL;
				break;
		}
	} else {
		key.key = command;
	}
	led_blink(LED_BLINK_PATTERN_SHORT);
	usb_keyboard_send_key(key);

}

// Sends a command to the PC, repeating if allowed.
void pc_command_send_repeating(enum pc_command_t command, uint8_t repeat_count) {
	
	// Is the key allowed to repeat?
	if (repeat_count > 0) {
		switch (command) {
			case PC_COMMAND_VOLUME_UP:
			case PC_COMMAND_VOLUME_DOWN:
				break;
			default:
				command = PC_COMMAND_NONE;
				break;
		}
	}
	
	// Send the command.
	pc_command_send(command);
}